==> haskell-regex-compat-0.95.1-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-regex-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-compat
version: 0.95.1
id: regex-compat-0.95.1-GpayP5pCY7oFkOLgNVrkag
key: regex-compat-0.95.1-GpayP5pCY7oFkOLgNVrkag
license: BSD-3-Clause
copyright: Copyright (c) 2006, Christopher Kuklewicz
maintainer: TextRegexLazy@personal.mightyreason.com
author: Christopher Kuklewicz
stability: Seems to work, passes a few tests
homepage: http://sourceforge.net/projects/lazy-regex
package-url: http://darcs.haskell.org/packages/regex-unstable/regex-compat/
synopsis: Replaces/Enhances Text.Regex
description:
    One module layer over regex-posix to replace Text.Regex
category: Text
abi: af6f71e3e9a26b52511ae7ff4847855c
exposed: True
exposed-modules:
    Text.Regex
import-dirs: /usr/lib/ghc-8.4.3/site-local/regex-compat-0.95.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/regex-compat-0.95.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/regex-compat-0.95.1
hs-libraries: HSregex-compat-0.95.1-GpayP5pCY7oFkOLgNVrkag
depends:
    array-0.5.2.0 base-4.11.1.0
    regex-base-0.93.2-98bD2PeVUkV8MO804tnXmq
    regex-posix-0.95.2-FLMmMz75XIwP5t3X8eXe
abi-depends: array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             regex-base-0.93.2-98bD2PeVUkV8MO804tnXmq=f1d7dcc91ebd3d0784eb457f5034301e
             regex-posix-0.95.2-FLMmMz75XIwP5t3X8eXe=eae15e0dc39513de0767dec8084921c8
haddock-interfaces: /usr/share/doc/haskell-regex-compat/html/regex-compat.haddock
haddock-html: /usr/share/doc/haskell-regex-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-compat-0.95.1-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-regex-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-compat
version: 0.95.1
id: regex-compat-0.95.1-HQ2rpMTK8sIBs9LHuyt5aA
key: regex-compat-0.95.1-HQ2rpMTK8sIBs9LHuyt5aA
license: BSD-3-Clause
copyright: Copyright (c) 2006, Christopher Kuklewicz
maintainer: TextRegexLazy@personal.mightyreason.com
author: Christopher Kuklewicz
stability: Seems to work, passes a few tests
homepage: http://sourceforge.net/projects/lazy-regex
package-url: http://darcs.haskell.org/packages/regex-unstable/regex-compat/
synopsis: Replaces/Enhances Text.Regex
description:
    One module layer over regex-posix to replace Text.Regex
category: Text
abi: 7ec5dedbf11334d6f00513c13caad66c
exposed: True
exposed-modules:
    Text.Regex
import-dirs: /usr/lib/ghc-8.6.1/site-local/regex-compat-0.95.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/regex-compat-0.95.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/regex-compat-0.95.1
hs-libraries: HSregex-compat-0.95.1-HQ2rpMTK8sIBs9LHuyt5aA
depends:
    array-0.5.2.0 base-4.12.0.0
    regex-base-0.93.2-BaAAthubc9o1zwSn6Umtk5
    regex-posix-0.95.2-BB6ZndJQrzY62dvJ2oZ3za
haddock-interfaces: /usr/share/doc/haskell-regex-compat/html/regex-compat.haddock
haddock-html: /usr/share/doc/haskell-regex-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
